==> serverless-workflow-service-calls-springboot-1.5.0.Final-sources.jar: org/kie/kogito/serverless/JsonservicecallModel.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.serverless;

import java.util.Map;
import java.util.HashMap;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "jsonservicecall", name = "Jsonservicecall", hidden = false)
public class JsonservicecallModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("workflowdata", this.workflowdata);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(getId(), params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.workflowdata = (com.fasterxml.jackson.databind.JsonNode) params.get("workflowdata");
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "workflowdata")
    @javax.validation.Valid()
    private com.fasterxml.jackson.databind.JsonNode workflowdata;

    public com.fasterxml.jackson.databind.JsonNode getWorkflowdata() {
        return workflowdata;
    }

    public void setWorkflowdata(com.fasterxml.jackson.databind.JsonNode workflowdata) {
        this.workflowdata = workflowdata;
    }

    public JsonservicecallModelOutput toOutput() {
        JsonservicecallModelOutput result = new JsonservicecallModelOutput();
        result.setId(getId());
        result.setWorkflowdata(getWorkflowdata());
        return result;
    }
}

==> serverless-workflow-service-calls-springboot-1.7.0.Final-sources.jar: org/kie/kogito/serverless/JsonservicecallModel.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.serverless;

import java.util.Map;
import java.util.HashMap;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "jsonservicecall", name = "Jsonservicecall", hidden = false)
public class JsonservicecallModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap<>();
        params.put("workflowdata", this.workflowdata);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(getId(), params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.workflowdata = (com.fasterxml.jackson.databind.JsonNode) params.get("workflowdata");
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "workflowdata")
    @javax.validation.Valid()
    private com.fasterxml.jackson.databind.JsonNode workflowdata;

    public com.fasterxml.jackson.databind.JsonNode getWorkflowdata() {
        return workflowdata;
    }

    public void setWorkflowdata(com.fasterxml.jackson.databind.JsonNode workflowdata) {
        this.workflowdata = workflowdata;
    }

    public JsonservicecallModelOutput toOutput() {
        JsonservicecallModelOutput result = new JsonservicecallModelOutput();
        result.setId(getId());
        result.setWorkflowdata(getWorkflowdata());
        return result;
    }
}
